Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolWriter");
;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
